from schema import Schema, And, Use, Optional, Regex

class AnalyticsValidator:
    def get_tiles_data(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid.")
        }
        Schema(schema).validate(args)

    def get_search_summary_chart(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid.")
        }
        Schema(schema).validate(args)

    def analytics_data_validation(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid."),
            'count': And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500")
        }
        Schema(schema).validate(args)

    def search_session_by_case_uid_auth(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'caseUID': And(Use(str), lambda s: len(s) > 0, error="Case UID is required."),
            'count': And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500")
        }
        Schema(schema).validate(args)

    def search_conversion_with_filters(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD")
        }
        Schema(schema).validate(args)

    def search_conversion_by_sessionid(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'count': And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500"),
            'sessionId': And(Use(str), lambda s: len(s) > 5, error="sessionId is required."),
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid.")
        }
        Schema(schema).validate(args)

    def get_search_session_by_search_sessionid(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'count': And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500"),
            'sessionId': And(Use(str), lambda s: len(s) > 5, error="sessionId is required."),
            Optional('pageNumber'): And(Use(int), lambda n: n >= 0, error="Invalid page number."),
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid.")
        }
        Schema(schema).validate(args)

    def get_discussions_ready_to_become_article(**args):
        schema = {
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'count': And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500"),
            Optional('internalUser'): str,
            Optional('searchClientId'): And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid.")
        }
        Schema(schema).validate(args)

    def case_created_validation(**args):
        schema = {
            'internalUser': str,
            'searchType': str,
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'searchClientId': And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid."),
            Optional('offset'): And(Use(int), lambda n: n > 0, error="offset should be greater than 0."),
            Optional('count'): And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500")
        }
        Schema(schema).validate(args)

    def get_attached_articles(**args):
        schema = {
            'internalUser': str,
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'searchClientId': And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid."),
            Optional('offset'): And(Use(int), lambda n: n > 0, error="offset should be greater than 0."),
            Optional('count'): And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500")
        }
        Schema(schema).validate(args)

    def get_attached_on_case(**args):
        schema = {
            'url': And(Use(str), Regex(r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"), error="Invalid Instance URL."),
            'startDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'endDate': And(Use(str), Regex(r'^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$'), error="Date format should be YYYY-MM-DD"),
            'searchClientId': And(Use(str), Regex(r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'), error="searchClientId format should be a uuid."),
            Optional('offset'): And(Use(int), lambda n: n > 0, error="offset should be greater than 0."),
            Optional('count'): And(Use(int), lambda n: 0 < n <= 500, error="Count should be 1-500")
        }
        Schema(schema).validate(args)



"""This library developed by searchunify. This library has various capabilities data pulling and pushing. This library gives the simple way to integrate SearchUnify API's"""
__author__ = "Mohan Rana"
__copyright__ = "Copyright 2021, SearchUnify"
__version__ = "1.0.1"
__maintainer__ = "SearchUnify"
__email__ = "mohanr@grazitti.com"

from searchunify.main import Searchunify


from searchunify.utils.validation.analytics import AnalyticsValidator
from searchunify.utils.validation.content import ContentValidator
from searchunify.utils.validation.search import SearchValidator
from searchunify.core.search.search import Search
from searchunify.core.content.contents import Content
from searchunify.core.analytics.analytics import Analytics
from searchunify.core.auth.oauth2 import Oauth2
from searchunify.utils.constants.constants import Constants, AuthVariables
from searchunify.client.client import Client

CONSTANTS = Constants()
AUTH_VARS = AuthVariables()

class Searchunify:
    """
    Used to initialize SearchUnify client. 
    Provide SearchUnify instance url, username, password, client_id and client_secret.
    """
    def __init__(self, **props):
        try:
            Client.authentication_type_validation(props)
            if (CONSTANTS.OAUTH2_DEL == AUTH_VARS.AUTH_TYPE):
               Oauth2.generate_access_token(props)
        except Exception as error:
            raise Exception(error)

    def refresh_token(self):
        """
        Get accessToken from refresh token.
        """
        try:
            response = Oauth2.access_token_from_refresh_token()
            return response
        except Exception as error:
            raise Exception(error)

    def get_tiles_data(self, **props):
        """
        Used to get information about visitors, search users, clicks, results, cases, and other essential search behavior.
        """
        try:
            AnalyticsValidator.get_tiles_data(**props)
            response = Analytics.get_tiles_data(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_search_summary_chart(self, **props):
        """
        Return Searches with Results, and All Searches with Clicks (conversions) have changed over the period between startDate and endDate.
        """
        try:
            AnalyticsValidator.get_search_summary_chart(**props)
            response = Analytics.get_search_summary_chart(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_all_search_query(self, **props):
        """
        Returns the most popular search queries over the period from startDate to endDate.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.get_all_search_query(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_search_queries_with_result(self, **props):
        """
        Returns the most popular search queries for which results were found.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.get_search_queries_with_result(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_queries_with_no_clicks(self, **props):
        """
        Returns the most popular search queries for which results were found but users didn't click on any of them.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.search_queries_with_no_clicks(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_queries_without_result(self, **props):
        """
        Returns the most popular search queries for which no results were found.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.search_queries_without_result(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_query_histogram(self, **props):
        """
        Returns search and conversion data over the period between startDate and endDate.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.search_query_histogram(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def missed_query_histogram(self, **props):
        """
        Returns the total number of queries that didn't produce even one result. The data is for the period between startDate and endDate.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.missed_query_histogram(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_session_by_case_uid_auth(self, **props):
        """
        Return the activity on a case.
        """
        try:
            AnalyticsValidator.search_session_by_case_uid_auth(**props)
            response = Analytics.search_session_by_case_uid_auth(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_all_search_conversion(self, **props):
        """
        Return a list of the count most popular documents. The data is from between startDate and endDate on a search client whose ID is searchClientID.
        If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.get_all_search_conversion(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_conversion_not_On_first_page(self, **props):
        """
        Return a list of the count documents that are not on the first page. These documents can be boosted to enhance search experience.
        The data is from between startDate and endDate on a search client whose ID is searchClientID. If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.search_conversion_not_On_first_page(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_conversion_with_filters(self, **props):
        """
        Return a chart of the popularity of all your content sources.
        The data is presented in an alphabetical order and includes:
        objectName, objectData, filterName, filterData, facetName, and facetName.
        An objectName is a content type and a filter is a high-level facet.
        The data is from between startDate and endDate.
        """
        try:
            AnalyticsValidator.search_conversion_with_filters(**props)
            response = Analytics.search_conversion_with_filters(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_conversion_by_sessionid(self, **props):
        """
        Return a list of the count most popular searches in a session.
        The data is from between startDate and endDate on a search client whose ID is searchClientID.
        If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.search_conversion_by_sessionid(**props)
            response = Analytics.search_conversion_by_sessionid(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_search_session_by_search_sessionid(self, **props):
        """
        Return a list of the count queries in a search session and the documents accessed during that session.
        The data is from between startDate and endDate on a search client whose ID is searchClientID.
        If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.get_search_session_by_search_sessionid(**props)
            response = Analytics.get_search_session_by_search_sessionid(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_discussions_ready_to_become_article(self, **props):
        """
        Return count discussions that have been accessed the most and can be converted into articles.
        The data is from between startDate and endDate.
        """
        try:
            AnalyticsValidator.get_discussions_ready_to_become_article(**props)
            response = Analytics.discussions_ready_to_become_article(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def search_queries_in_sessions(self, **props):
        """
        Return a list of the count search sessions and the searches conducted in each session.
        The data is from between startDate and endDate on a search client whose ID is searchClientID.
        If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.search_queries_in_sessions(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_kcs_support_search_query(self, **props):
        """
        Return the number of articles generated on your cases between startDate and endDate on a search client whose ID is searchClientID.
        If the searchClientID is not specified, then the call fetches data from all the search clients.
        """
        try:
            AnalyticsValidator.analytics_data_validation(**props)
            response = Analytics.get_kcs_support_search_query(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_search_session_by_case_uid(self, **props):
        """
        Return search, conversion, page views, case deflection, and case creation data for the argument caseUid.
        """
        try:
            AnalyticsValidator.search_session_by_case_uid_auth(**props)
            response = Analytics.get_search_session_by_case_uid(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_case_created_articles(self, **props):
        """
        Return the list of articles that were consulted before a user created a case.
        """
        try:
            AnalyticsValidator.case_created_validation(**props)
            response = Analytics.get_case_created_articles(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_case_deflected_articles(self, **props):
        """
        Returns the articles that were consulted by users who didn't create a case.
        """
        try:
            AnalyticsValidator.case_created_validation(**props)
            response = Analytics.get_case_deflected_articles(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_attached_articles(self, **props):
        """
        Return how many articles have been attached to cases.
        """
        try:
            AnalyticsValidator.get_attached_articles(**props)
            response = Analytics.get_attached_articles(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_attached_on_case(self, **props):
        """
        From the article URL, find out which cases it has been attached to.
        """
        try:
            AnalyticsValidator.get_attached_on_case(**props)
            response = Analytics.get_attached_on_case(**props)
            return response
        except Exception as error:
            raise Exception(error)

    # content source methods.
    def get_content_sources(self):
        """
        Used to list all added content sources in SearchUnify instance.
        """
        try:
            response = Content.get_content_sources()
            return response
        except Exception as error:
            raise Exception(error)

    def get_content_source_by_id(self, **props):
        """
        Used to get particular content source.
        You need pass contentSourceId as a parameter particular content source.
        """
        try:
            ContentValidator.content_source_id_validation(**props)
            response = Content.get_content_source_by_id(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_object_and_fields(self, **props):
        """
        Used to get content source objects and fileds.
        """
        try:
            ContentValidator.content_source_id_validation(**props)
            response = Content.get_object_and_fields(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_object_specific_data(self, **props):
        """
        If you have multiple objects type. You can get data from particular object by this method.
        """
        try:
            ContentValidator.get_object_specific_data(**props)
            response = Content.get_object_specific_data(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def get_object_specific_data_with_id(self, **props):
        """
        Used to get data from a specific object type and specific document id.
        """
        try:
            ContentValidator.get_object_specific_data_with_id(**props)
            response = Content.get_object_specific_data_with_id(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def update_doucment_by_id(self, **props):
        """
        Used to update particular document in SearchUnify index.
        """
        try:
            ContentValidator.update_doucment_by_id(**props)
            response = Content.update_doucment_by_id(**props)
            return response
        except Exception as error:
            raise Exception(error)

    def upload_data(self, **props):
        """
        Used to index multiple document at a time.
        """
        try:
            ContentValidator.upload_data(**props)
            response = Content.upload_data(**props)
            return response
        except Exception as error:
            raise Exception(error)

    # Search methods
    def get_search_results(self, **props):
        """
        Used to search content from a particular plateform.
        Pass uid, searchString and other optional parameters as per requirement.
        """
        try:
            SearchValidator.get_search_results(**props)
            response = Search.get_search_results(**props)
            return response
        except Exception as error:
            raise Exception(error)



from searchunify.utils.http_client.request_handler import RequestManager
from searchunify.core.auth.auth_header_type import get_auth_header
from searchunify.utils.constants.constants import AuthVariables
from searchunify.utils.apis.apis import Apis
import json

API = Apis.get_apis('search')
AUTH_VARS = AuthVariables()

class Search:
    def get_search_results(**payload):
        url = AUTH_VARS.INSTANCE + API['searchResults']
        payload = json.dumps(payload)
        response = RequestManager.http_request(
            "POST", url, headers=get_auth_header(), data=payload)
        return response



# This file contains variables.

class Constants():
    OAUTH2_DEL = 'oauth2'
    JWT_KEY_DEL = 'jwtKey'
    API_KEY_DEL = 'apiKey'
    GRANT_TYPE = 'password'
    GRANT_TYPE_REFRESH_TOKEN = 'refresh_token'

class AuthVariables():
    def __init__(self):
        self._INSTANCE = None
        self._AUTH_TYPE = None
        self._ACCESS_TOKEN = None
        self._REFRESH_TOKEN = None
        self._JWT_TOKEN = None
        self._API_TOKEN = None
        self._CLIENT_ID = None
        self._SECRETS = None

    @property
    def INSTANCE(self):
        return self._INSTANCE

    @property
    def AUTH_TYPE(self):
        return self._AUTH_TYPE

    @property
    def ACCESS_TOKEN(self):
        return self._ACCESS_TOKEN

    @property
    def REFRESH_TOKEN(self):
        return self._REFRESH_TOKEN

    @property
    def JWT_TOKEN(self):
        return self._JWT_TOKEN

    @property
    def API_TOKEN(self):
        return self._API_TOKEN
        
    @property
    def CLIENT_ID(self):
        return self._CLIENT_ID

    @property
    def SECRETS(self):
        return self._SECRETS

    @INSTANCE.setter
    def INSTANCE(self, value):
        self._INSTANCE = value

    @AUTH_TYPE.setter
    def AUTH_TYPE(self, value):
        self._AUTH_TYPE = value

    @ACCESS_TOKEN.setter
    def ACCESS_TOKEN(self, value):
        self._ACCESS_TOKEN = value

    @REFRESH_TOKEN.setter
    def REFRESH_TOKEN(self, value):
        self._REFRESH_TOKEN = value

    @JWT_TOKEN.setter
    def JWT_TOKEN(self, value):
        self._JWT_TOKEN = value

    @API_TOKEN.setter
    def API_TOKEN(self, value):
        self._API_TOKEN = value
        
    @CLIENT_ID.setter
    def CLIENT_ID(self, value):
        self._CLIENT_ID = value

    @SECRETS.setter
    def SECRETS(self, value):
        self._SECRETS = value


from searchunify.utils.validation.oauth2 import OauthValidator
from searchunify.utils.constants.constants import *

AUTH_VARS = AuthVariables()
CONSTANTS = Constants()

class Client:
    def authentication_type_validation(client):
        OauthValidator.instance_url(**client)
        AuthVariables.INSTANCE = client.get('instance').strip('/')
        if(client.get('client_id') and client.get('client_secret')):
            OauthValidator.access_token(**client)
            AuthVariables.AUTH_TYPE = CONSTANTS.OAUTH2_DEL
            AuthVariables.CLIENT_ID = client.get('client_id')
            AuthVariables.SECRETS = client.get('client_secret')

        elif(client.get('api_token')):
            OauthValidator.api_key_token(**client)
            AuthVariables.AUTH_TYPE = client.get('api_token')
            AuthVariables.AUTH_TYPE = CONSTANTS.API_KEY_DEL

        elif(client.get('jwt_token')):
            OauthValidator.jwt_token(**client)
            AuthVariables.JWT_TOKEN = client.get('jwt_token')
            AuthVariables.AUTH_TYPE = CONSTANTS.JWT_KEY_DEL

        else:
            raise Exception('Incomplete client parameters.')
            


from schema import Schema, And, Use, Regex

class OauthValidator:
    def instance_url(**args):
        schema = {
            'instance': And(Use(str), Regex(r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"), error="Invalid Instance URL.")
        }
        Schema(schema, ignore_extra_keys=True).validate(args)

    def access_token(**args):
        schema = {
            'username': And(Use(str), lambda s: len(s) > 0, error="username is required."),
            'password': And(Use(str), lambda s: len(s) > 0, error="password is required."),
            'client_id': And(Use(str), lambda s: len(s) > 0, error="client_id is required."),
            'client_secret': And(Use(str), lambda s: len(s) > 0, error="client_secret is required.")
        }
        Schema(schema, ignore_extra_keys=True).validate(args)

    def api_key_token(**args):
        schema = {
            'api_token': And(Use(str), lambda s: len(s) > 0, error="api_token is required.")
        }
        Schema(schema, ignore_extra_keys=True).validate(args)

    def jwt_token(**args):
        schema = {
            'jwt_token': And(Use(str), lambda s: len(s) > 0, error="jwt_token is required.")
        }
        Schema(schema, ignore_extra_keys=True).validate(args)





#!/usr/bin/env python

from setuptools import find_packages, setup

requires = [
    'requests==2.23.0', 
    'schema==0.7.4'
]

setup(
    include_package_data=True,
    name="searchunify",
    version='1.0.5',
    description='The SearchUnify SDK enables developers to easily work with the SearchUnify platform and build scalable solutions with search, analytics, crawlers and more.',
    long_description_content_type='text/markdown',
    long_description=open('README.md').read(),
    author='SearchUnify',
    author_email='ankur.mahajan@grazitti.com',
    url='https://www.searchunify.com/',
    packages=find_packages(exclude=['tests*']),
    install_requires=requires,
    license="MIT",
    python_requires=">= 3",
    project_urls={
        'Documentation': 'https://docs.searchunify.com/Content/Developer-Guides/SDKs-Python.htm',
        'Source': 'https://github.com/searchunify/su-sdk-python',
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],

)